local lg = assert( love.graphics )
local love = assert( love )
local scene = assert( require 'client.scene' )
local strings = assert( require 'client.assets.strings' )
local button = assert( require 'client.button' )
local menu = {}

local t = 0
local wWidth = 800
local wHeight = 600

local selectedButtonIdx = nil

local buttons = 
  {
    button{ 
      x = 15, w = 400, h = 50,
      y = 115,
      text = strings.option_name,
      color = { 0.5, 0.7, 0.5, 1 },
      callback = function() print("Adjust Name") end },
    
    button{ 
      x = 15, w = 400, h = 50,
      y = 115 + 55,
      text = strings.option_pron,
      color = { 0.5, 0.7, 0.5, 1 },
      callback = function() print("Adjust Name") end },
    
    button{ 
      x = 15, w = 400, h = 50,
      y = 115 + 55 * 2,
      text = strings.option_tint,
      color = { 0.5, 0.7, 0.5, 1 },
      callback = function() print("Adjust Colour") end },
    
    button{
      x = 15, w = 400, h = 50,
      y = 115 + 55 * 3,
      text = strings.mainmenu_button,
      color = { 0.5, 0.7, 0.5, 1 },
      callback = function() print("Adjust Name") return scene.mainmenu() end },
  }

function menu.onLoad()
end

function menu.draw()
  for id, button in pairs( buttons ) do button:draw( ) end
end

function menu.update( dt )
  t = t + dt
end

function menu.resize( w, h )
  wWidth, wHeight = w, h
end

function menu.mousemoved( x, y, dx, dy, istouch )
  if selectedButtonIdx then
    buttons[selectedButtonIdx].selected = false
    selectedButtonIdx = nil
  end
  for id, menuButton in ipairs( buttons ) do
    if menuButton:contains( x, y ) then
      menuButton.selected = true
      selectedButtonIdx = id
      break
    end
  end
end

function menu.mousepressed( x, y, button, istouch, presses )
  if not selectedButtonIdx then return end
  local uiButton = buttons[selectedButtonIdx]
  if uiButton:contains( x, y ) then return uiButton() end
end

function menu.keypressed( key, code, isrepeat )
  
  if code == "escape" then
    return scene.mainmenu()
  end
  
  if code == "return" and selectedButtonIdx then
    return buttons[selectedButtonIdx]()
  end
  
  if code == "down" or code == "tab" or code == "up" then
    local sbi = (selectedButtonIdx or 1)
    buttons[sbi].selected = false
    
    --Increment / decrement
    sbi = sbi + ((code == "up") and -1 or 1)
    if sbi > #buttons then sbi = 1 end
    if sbi < 1 then sbi = #buttons end
    
    --Assign
    print( "selecting button: ", sbi )
    selectedButtonIdx = sbi
    buttons[selectedButtonIdx].selected = true
  end
  
end

scene.options = menu
return menu